@@ -51,9 +51,9 @@ def initLogger(loggerName=None, loggerLevel=None, logFile=None):
                 # issue 35046: merged two stream.writes into one.
                 func = stream.write
                 if record.levelno == logging.WARNING:
-                    func = printcolor.yellow
+                    func = printcolor.darkYellow
                 elif record.levelno == logging.ERROR:
-                    func = printcolor.red
+                    func = printcolor.darkRed
                 elif record.levelno == logging.CRITICAL:
                     func = printcolor.pink
                 func(msg)
